# aceso [![PyPI version](https://badge.fury.io/py/aceso.svg)](https://badge.fury.io/py/aceso) [![Build Status](https://travis-ci.org/tetraptych/aceso.svg?branch=master)](https://travis-ci.org/tetraptych/unrasterize) [![Coverage Status](https://coveralls.io/repos/github/tetraptych/aceso/badge.svg?branch=master)](https://coveralls.io/github/tetraptych/aceso?branch=master) [![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
Aceso is a lightweight package to calculate 2SFCA and other measures of spatial accessibility.

This package shares a name with [the Greek goddess of the healing process](https://en.wikipedia.org/wiki/Aceso). The two go hand-in-hand, since the most common applications of 2SFCA and gravity models of spatial interaction are for measuring spatial access to healthcare services.

## Installation

`aceso` is available on [PyPI](https://pypi.org/project/aceso/) and can be installed via the following command:

```
pip install aceso
```

The only dependency is `numpy`.

## Gallery

![Potential spatial access to abortion clinics in Texas (2017)](https://farm1.staticflickr.com/902/39848822400_197406d944_z_d.jpg "Gravity model using raised cosine decay with 3 hour driving radius")
